@@ -8,6 +8,16 @@
 #' @keywords datasets
 NULL
 
+#' Datasets
+#' Differential expression analysis result of GSE42872
+#'
+#'
+#' @name Datasets
+#' @aliases deg
+#' @docType data
+#' @keywords datasets
+NULL
+
 #' Datasets
 #' msig_species contains msigdb species information
 #'
