@@ -12,10 +12,10 @@
 #' @param maxGSSize Maximal size of each geneSet for analyzing, default is 500.
 #' @param pvalueCutoff Adjusted pvalue cutoff, default is 0.05.
 #' @param ... Other argument to `GSEA` function
-#' @importFrom dplyr select filter pull mutate %>%
+#' @importFrom dplyr select filter arrange pull mutate
 #' @importFrom stringr str_split
+#' @importFrom stringi stri_remove_empty_na
 #' @importFrom clusterProfiler GSEA
-#' @importFrom stats na.omit
 #' @importFrom rlang .data
 #'
 #' @return GSEA list
@@ -61,7 +61,7 @@ genGSEA <- function(genelist,
     geneset <- geneset %>%
       dplyr::select(gs_name, entrez_gene)
   } else {
-    names(genelist) <- transId(names(genelist), trans_to = "entrez", org)
+    names(genelist) <- transId(names(genelist), transTo = "entrez", org)
     geneset <- geneset %>%
       dplyr::select(gs_name, entrez_gene)
   }
@@ -77,13 +77,21 @@ genGSEA <- function(genelist,
 
   egmt =  egmt %>% as.data.frame() %>% as.enrichdat()
   if( use_symbol){
-    info = genInfo(unique(unlist(stringr::str_split(egmt$geneID,'\\/'))),org,unique = T)
-    new_geneID = stringr::str_split(egmt$geneID,'\\/') %>%
+    # transform id to symbol
+    egmt_id = stringr::str_split(egmt$geneID,'\\/') %>% unlist()
+    id_all = suppressMessages(transId(egmt_id,'symbol',org = org))
+
+    new_geneID <- stringr::str_split(egmt$geneID, "\\/") %>%
       lapply(., function(x) {
-        info %>% dplyr::filter(input_id %in% x) %>% dplyr::pull(symbol)
-      }) %>% sapply(., paste0, collapse = "/")
+        id_all %>% dplyr::filter(input_id %in% x) %>%
+          dplyr::arrange(match(input_id, x)) %>%
+          dplyr::pull(symbol)
+      }) %>%
+      sapply(., paste0, collapse = "/")
+
     egmt =  egmt %>%
-      dplyr::mutate(geneID = new_geneID)
+      dplyr::mutate(geneID_symbol = new_geneID) %>%
+      dplyr::relocate(geneID_symbol,.after = geneID)
   }
 
   res <- list(genelist = genelist, geneset = geneset, gsea_df = egmt, exponent = exponent, org = org)
