@@ -3,7 +3,6 @@
 #' @param id A vector of entrez gene.
 #' @param group_list A list of gene id groups, default is NULL.
 #' @param org  KEGG organism name from `keggOrg_name`.
-#' @param use_symbol Logical to set result gene id as gene symbol, default is TRUE.
 #' @param pAdjustMethod One of "holm", "hochberg", "hommel", "bonferroni", "BH",
 #'   "BY", "fdr", "none".
 #' @param pvalueCutoff Numberic of adjusted pvalue cutoff, default is 0.05.
@@ -15,11 +14,9 @@
 #' @param universe Background genes. If missing, the orgdb all gene list will be
 #'   used as background.
 #' @param ... Other argument to `enrichKEGG` function
-#' @importFrom dplyr  %>% mutate filter
-#' @importFrom stringr  str_split
-#' @importFrom stringi stri_omit_na
+#' @importFrom dplyr pull filter arrange mutate relocate
+#' @importFrom stringr str_split
 #' @importFrom clusterProfiler enrichKEGG
-#' @importFrom stats na.omit
 #' @importFrom rlang .data
 #'
 #' @return A `data.frame`.
@@ -29,24 +26,22 @@
 #' \dontrun{
 #' # only gene ids
 #' data(geneList, package = "genekitr")
-#' id <- names(geneList)[1:100]
+#' id <- names(geneList)[abs(geneList) > 1]
 #' keg <- genKEGG(id, org = "human")
 #'
 #' # gene id with groups
-#' id <- c(head(names(geneList),50),tail(names(geneList),50))
-#' group <- list(group1  = c(rep('up',50),rep('down',50)),
-#'               group2 = c(rep('A',40),rep('B',60)))
+#' id <- c(head(names(geneList),100),tail(names(geneList),100))
+#' group <- list(group1  = c(rep('up',100),rep('down',100)),
+#'               group2 = c(rep('A',130),rep('B',70)))
 #' gkeg <- genKEGG(id, group_list = group,
-#'               org = "human", pvalueCutoff = 0.1,
-#'               qvalueCutoff = 0.1, use_symbol = FALSE
-#' )
+#'               org = "human", pvalueCutoff = 0.05,
+#'               qvalueCutoff = 0.05)
 #'
 #' }
 #'
 genKEGG <- function(id,
                     group_list = NULL,
                     org,
-                    use_symbol = TRUE,
                     pAdjustMethod = "BH",
                     pvalueCutoff = 0.05,
                     qvalueCutoff = 0.1,
@@ -66,22 +61,20 @@ genKEGG <- function(id,
 
   if(full_latin %in% ensorg$latin_full_name){
     ens_org <- mapEnsOrg(full_latin)
-    keyType <- gentype(id, ens_org)
+    keyType <- gentype(id = id, org=ens_org)
     if (!keyType %in% c("ENTREZID")) {
       message(paste0(keyType), " gene will be mapped to entrez id")
-      trans_id <- suppressMessages(transId(id, "entrezid", ens_org)) %>% stringi::stri_remove_na()
+      trans_id <- suppressMessages(transId(id, "entrezid", ens_org)) %>%
+        dplyr::pull(entrezid)
     }else{
       trans_id <- id
     }
-    info <- genInfo(trans_id, ens_org, unique = T)
-
   }else{
     trans_id <- id
-    use_symbol <- FALSE
   }
 
   #--- codes ---#
-  ## only gene ids
+  ## NO GROUP INFO
   if(is.null(group_list)){
     keg <- suppressMessages(
       clusterProfiler::enrichKEGG(
@@ -100,27 +93,27 @@ genKEGG <- function(id,
       stop("No KEGG terms enriched ...")
     }
 
-    if (use_symbol) {
-      new_geneID <- stringr::str_split(keg$geneID, "\\/") %>%
-        lapply(., function(x) {
-          info %>%
-            dplyr::filter(input_id %in% x) %>%
-            dplyr::pull(symbol)
-        }) %>%
-        sapply(., paste0, collapse = "/")
-      new_keg <- keg %>%
-        as.data.frame() %>%
-        dplyr::mutate(geneID = new_geneID) %>%
-        calcFoldEnrich() %>%
-        as.enrichdat()
-    } else {
-      new_keg <- keg %>%
-        as.data.frame() %>%
-        calcFoldEnrich() %>%
-        as.enrichdat()
-    }
+    # transform entrez id to symbol
+    keg_id = stringr::str_split(keg$geneID, "\\/") %>% unlist()
+    id_all = suppressMessages(transId(keg_id,'symbol',org = org,unique = T))
+
+    new_geneID <- stringr::str_split(keg$geneID, "\\/") %>%
+      lapply(., function(x) {
+        id_all %>% dplyr::filter(input_id %in% x) %>%
+          dplyr::arrange(match(input_id, x)) %>%
+          dplyr::pull(symbol)
+      }) %>%
+      sapply(., paste0, collapse = "/")
+
+    new_keg <- keg %>%
+      as.data.frame() %>%
+      dplyr::mutate(geneID_symbol = new_geneID) %>%
+      dplyr::relocate(geneID_symbol,.after = geneID) %>%
+      calcFoldEnrich() %>%
+      as.enrichdat()
+
   }else{
-    ## gene id plus groups
+    ## WITH GROUP INFO
     df <- as.data.frame(group_list) %>% dplyr::mutate(id = id)
     lkeg <- clusterProfiler::compareCluster(eval(parse(text =paste0('id~',paste(colnames(df)[-ncol(df)],collapse = '+')))),
                                             data=df,
@@ -136,31 +129,34 @@ genKEGG <- function(id,
     if (nrow(as.data.frame(lkeg)) == 0) {
       stop("No KEGG terms enriched ...")
     }
-    if (use_symbol) {
-      new_geneID <- stringr::str_split(lkeg@compareClusterResult$geneID, "\\/") %>%
-        lapply(., function(x) {
-          info %>%
-            dplyr::filter(input_id %in% x) %>%
-            dplyr::pull(symbol)
-        }) %>%
-        sapply(., paste0, collapse = "/")
-      new_keg <- lkeg %>%
-        as.data.frame() %>%
-        dplyr::mutate(geneID = new_geneID) %>%
-        calcFoldEnrich() %>%
-        as.enrichdat()
-    } else {
-      new_keg <- lkeg %>%
-        as.data.frame() %>%
-        calcFoldEnrich() %>%
-        as.enrichdat()
-    }
+    # transform entrez id to symbol
+    keg_id = stringr::str_split(lkeg@compareClusterResult$geneID, "\\/") %>% unlist()
+    id_all = suppressMessages(transId(keg_id,'symbol',org = org,unique = T))
+
+    new_geneID <- stringr::str_split(lkeg@compareClusterResult$geneID, "\\/") %>%
+      lapply(., function(x) {
+        id_all %>% dplyr::filter(input_id %in% x) %>%
+          dplyr::arrange(match(input_id, x)) %>%
+          dplyr::pull(symbol)
+      }) %>%
+      sapply(., paste0, collapse = "/")
+
+    new_keg <- lkeg %>%
+      as.data.frame() %>%
+      dplyr::mutate(geneID_symbol = new_geneID) %>%
+      dplyr::relocate(geneID_symbol,.after = geneID) %>%
+      calcFoldEnrich() %>%
+      as.enrichdat()
 
   }
 
+  # add rich factor
+  new_keg <- new_keg %>%
+    dplyr::mutate(RichFactor = Count/as.numeric(sub("/\\d+","", BgRatio)))
+
   return(new_keg)
 }
 
 
-utils::globalVariables(c("input_id","symbol"))
+utils::globalVariables(c("input_id","symbol","entrezid"))
 
